@@ -77,6 +77,12 @@ def modelfile():
     "-w",
     help="Please provide the workspace id if you would like to override the default target workspace. If your current Azure Active Directory login does not have access to this workspace, you will need to configure the workspace using bonsai configure.",
 )
+@click.option(
+    "--compute-type",
+    default="AzureContainerInstance",
+    help="(experimental) select the simulator compute infrastructure. choose from [AzureContainerInstance (default) | AzureKubernetesService]",
+    hidden=True,
+)
 @click.option(
     "--managed-app-resourcegroup-name",
     help="ManagedApp ResourceGroupName under which managed app is currently running for the offer chosen.",
@@ -111,6 +117,7 @@ def create_modelfile_simulator_package(
     display_name: str,
     description: str,
     workspace_id: str,
+    compute_type: str,
     managed_app_resourcegroup_name: str,
     managed_app_name: str,
     os_type: str,
@@ -226,6 +233,7 @@ def create_modelfile_simulator_package(
             os_type=os_type,
             package_type="modelfile",
             workspace=workspace_id,
+            compute_type=compute_type,
             publisher_id=publisher_id,
             offer_id=offer_id,
             plan_id=plan_id,
